@@ -4,6 +4,8 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"os"
+	"strconv"
 	"strings"
 
 	"github.com/anthropics/anthropic-sdk-go"
@@ -49,6 +51,10 @@ func NewClient() (ret *Client) {
 		string(anthropic.ModelClaudeOpus4_1_20250805),
 	}
 
+	ret.modelBetas = map[string][]string{
+		string(anthropic.ModelClaudeSonnet4_20250514): {"context-1m-2025-08-07"},
+	}
+
 	return
 }
 
@@ -93,6 +99,7 @@ type Client struct {
 	maxTokens                  int
 	defaultRequiredUserMessage string
 	models                     []string
+	modelBetas                 map[string][]string
 
 	client anthropic.Client
 }
@@ -148,6 +155,26 @@ func (an *Client) ListModels() (ret []string, err error) {
 	return an.models, nil
 }
 
+func parseThinking(level domain.ThinkingLevel) (anthropic.ThinkingConfigParamUnion, bool) {
+	lower := strings.ToLower(string(level))
+	switch domain.ThinkingLevel(lower) {
+	case domain.ThinkingOff:
+		disabled := anthropic.NewThinkingConfigDisabledParam()
+		return anthropic.ThinkingConfigParamUnion{OfDisabled: &disabled}, true
+	case domain.ThinkingLow, domain.ThinkingMedium, domain.ThinkingHigh:
+		if budget, ok := domain.ThinkingBudgets[domain.ThinkingLevel(lower)]; ok {
+			return anthropic.ThinkingConfigParamOfEnabled(budget), true
+		}
+	default:
+		if tokens, err := strconv.ParseInt(lower, 10, 64); err == nil {
+			if tokens >= 1 && tokens <= 10000 {
+				return anthropic.ThinkingConfigParamOfEnabled(tokens), true
+			}
+		}
+	}
+	return anthropic.ThinkingConfigParamUnion{}, false
+}
+
 func (an *Client) SendStream(
 	msgs []*chat.ChatCompletionMessage, opts *domain.ChatOptions, channel chan string,
 ) (err error) {
@@ -160,7 +187,17 @@ func (an *Client) SendStream(
 
 	ctx := context.Background()
 
-	stream := an.client.Messages.NewStreaming(ctx, an.buildMessageParams(messages, opts))
+	params := an.buildMessageParams(messages, opts)
+	betas := an.modelBetas[opts.Model]
+	var reqOpts []option.RequestOption
+	if len(betas) > 0 {
+		reqOpts = append(reqOpts, option.WithHeader("anthropic-beta", strings.Join(betas, ",")))
+	}
+	stream := an.client.Messages.NewStreaming(ctx, params, reqOpts...)
+	if stream.Err() != nil && len(betas) > 0 {
+		fmt.Fprintf(os.Stderr, "Anthropic beta feature %s failed: %v\n", strings.Join(betas, ","), stream.Err())
+		stream = an.client.Messages.NewStreaming(ctx, params)
+	}
 
 	for stream.Next() {
 		event := stream.Current()
@@ -226,6 +263,11 @@ func (an *Client) buildMessageParams(msgs []anthropic.MessageParam, opts *domain
 			{OfWebSearchTool20250305: &webTool},
 		}
 	}
+
+	if t, ok := parseThinking(opts.Thinking); ok {
+		params.Thinking = t
+	}
+
 	return
 }
 
@@ -239,8 +281,21 @@ func (an *Client) Send(ctx context.Context, msgs []*chat.ChatCompletionMessage,
 	}
 
 	var message *anthropic.Message
-	if message, err = an.client.Messages.New(ctx, an.buildMessageParams(messages, opts)); err != nil {
-		return
+	params := an.buildMessageParams(messages, opts)
+	betas := an.modelBetas[opts.Model]
+	var reqOpts []option.RequestOption
+	if len(betas) > 0 {
+		reqOpts = append(reqOpts, option.WithHeader("anthropic-beta", strings.Join(betas, ",")))
+	}
+	if message, err = an.client.Messages.New(ctx, params, reqOpts...); err != nil {
+		if len(betas) > 0 {
+			fmt.Fprintf(os.Stderr, "Anthropic beta feature %s failed: %v\n", strings.Join(betas, ","), err)
+			if message, err = an.client.Messages.New(ctx, params); err != nil {
+				return
+			}
+		} else {
+			return
+		}
 	}
 
 	var textParts []string
